Struct CacheMissing

pub struct CacheMissing<B: BlockStore> {
    pub inner: B,
    /* private fields */
}
A wrapper struct for a BlockStore that attaches an in-memory cache of which blocks are available and which aren’t, speeding up consecutive has_block and get_block calls.

Fields

inner: B

Access to the inner blockstore

Implementations

Source

impl<B: BlockStore> CacheMissing<B>

pub fn new(approx_capacity: usize, inner: B) -> Self

Wrap an existing BlockStore, caching has_block responses.

This will also intercept get_block requests and fail early, if the block is known to be missing. In some circumstances this can be problematic, e.g. if blocks can be added and removed to the underlying blockstore without going through the wrapped instance’s put_block or put_block_keyed interfaces.

In these cases a more advanced caching strategy that may answer has_block early from a cache with a cache TTL & eviction strategy.

The additional memory requirements for this cache can be estimated using the approx_capacity: Each cache line is roughly ~100 bytes in size, so for a 100MB cache, set this value to 1_000_000.