Struct Config

pub struct Config {
    pub receive_maximum: usize,
    pub max_block_size: usize,
    pub max_roots_per_round: usize,
    pub bloom_fpr: fn(u64) -> f64,
}
Configuration values (such as byte limits) for the CAR mirror protocol

Fields

receive_maximum: usize

The maximum number of bytes per request that a recipient should accept.

This only has an effect in non-streaming versions of this protocol. In streaming versions, car-mirror will check the validity of each block while streaming.

By default this is 2MB.

max_block_size: usize

The maximum number of bytes per block.

As long as we can’t verify the hash value of a block, we can’t verify if we’ve been given the data we actuall want or not, thus we need to put a maximum value on the byte size that we accept per block.

By default this is 1MB.

1MB is also the default maximum block size in IPFS’s bitswap protocol. 256KiB is the default maximum block size that Kubo produces by default when generating UnixFS blocks.

iroh-car internally has a maximum 4MB limit on a CAR file frame (CID + block), so any value above 4MB doesn’t work.

max_roots_per_round: usize

The maximum number of roots per request that will be requested by the recipient to be sent by the sender.

By default this is 1_000.

bloom_fpr: fn(u64) -> f64

The target false positive rate for the bloom filter that the recipient sends.

By default it’s set to |num| min(0.001, 0.1 / num).

This default means bloom filters will aim to have a false positive probability one order of magnitude under the number of elements. E.g. for 100_000 elements, a false positive probability of 1 in 1 million.